<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ms">
<context>
    <name>AddPrinterTask</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="551"/>
        <source>URI and driver do not match.</source>
        <translation>Pemacu URI tidak sepadan.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="553"/>
        <source>Install hplip first and restart the app to install the driver again.</source>
        <translation>Pasang hplip dahulu kemudian mula semula apl untuk memasang pemacu sekali lagi.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="561"/>
        <source>Please select an hplip driver and try again.</source>
        <translation>Sila pilih satu pemacu hplip dan cuba sekali lagi.</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="574"/>
        <source>URI can&apos;t be empty</source>
        <translation>URI tidak boleh kosong</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="581"/>
        <source> not found</source>
        <translation>tidak ditemui</translation>
    </message>
</context>
<context>
    <name>CheckAttributes</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="305"/>
        <source>Check printer settings</source>
        <translation>Semak tetapan pencetak</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="314"/>
        <source>Checking printer settings...</source>
        <translation>Memeriksa tetapan pencetak...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="317"/>
        <source>Success</source>
        <translation>Berjaya</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="327"/>
        <source>Failed to get printer attributes, error: </source>
        <translation>Gagal mendapatkan atribut-atribut pencetak, ralat:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="335"/>
        <source>%1 is disabled</source>
        <translation>%1 dilumpuhkan</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="344"/>
        <source>is not accepting jobs</source>
        <translation>tidak menerima kerja</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="349"/>
        <source>Printer settings are ok</source>
        <translation>Tetapan pencetak adalah ok</translation>
    </message>
</context>
<context>
    <name>CheckConnected</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="211"/>
        <source>Check printer connection</source>
        <translation>Periksa sambungan pencetak</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="223"/>
        <source>Checking printer connection...</source>
        <translation>Memeriksa sambungan pencetak...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="226"/>
        <source>Success</source>
        <translation>Berjaya</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="263"/>
        <source>Cannot connect to the printer, error: %1</source>
        <translation>Tidak dapat bersambung dengan pencetak, ralat: %1</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="271"/>
        <source> is not connected, URI: </source>
        <translation>tidak bersambung, URI:</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="280"/>
        <source>%1 does not exist</source>
        <translation>%1 tidak wujud</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="288"/>
        <source>Cannot connect to the printer</source>
        <translation>Tidak dapat bersambung dengan pencetak</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="294"/>
        <source>The connection is valid</source>
        <translation>Sambungan adalah sah</translation>
    </message>
</context>
<context>
    <name>CheckCupsServer</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="109"/>
        <source>Check CUPS server</source>
        <translation>Periksa pelayan CUPS</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="115"/>
        <source>Checking CUPS server...</source>
        <translation>Memeriksa pelayan CUPS...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="117"/>
        <source>CUPS server is invalid</source>
        <translation>Pelayan CUPS adalah tidak sah</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="122"/>
        <source>CUPS server is valid</source>
        <translation>Pelayan CUPS adalah sah</translation>
    </message>
</context>
<context>
    <name>CheckDriver</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="140"/>
        <source>Checking driver...</source>
        <translation>Memeriksa pemacu...</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="143"/>
        <source>Success</source>
        <translation>Berjaya</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="151"/>
        <source>PPD file %1 not found</source>
        <translation>Fail PPD %1 tidak ditemui</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="161"/>
        <source>The driver is damaged</source>
        <translation>Pemacu telah rosak</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="177"/>
        <source>Driver filter %1 not found</source>
        <translation>Penapis pemacu %1 tidak ditemui</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="189"/>
        <source>%1 is not installed, cannot print now</source>
        <translation>%1 tidak dipasang, tidak dapat mencetak sekarang</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="195"/>
        <source>Driver is valid</source>
        <translation>Pemacu adalah sah</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="201"/>
        <source>Check driver</source>
        <translation>Periksa pemacu</translation>
    </message>
</context>
<context>
    <name>CupsMonitor</name>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="99"/>
        <source>Queuing</source>
        <translation>Membaris gilir</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="100"/>
        <source>Paused</source>
        <translation>Dijeda</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="101"/>
        <source>Printing</source>
        <translation>Mencetak</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="102"/>
        <source>Stopped</source>
        <translation>Terhenti</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="103"/>
        <source>Canceled</source>
        <translation>Dibatalkan</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="104"/>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="105"/>
        <source>Completed</source>
        <translation>Selesai</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="369"/>
        <source>%1 timed out, reason: %2</source>
        <translation>%1 telah tamat masa, sebab: %2</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="383"/>
        <source>%1 has been sent to the printer, please take away the paper in time!</source>
        <translation>%1 telah dihantar ke pencetak, sila alih keluar kertas!</translation>
    </message>
    <message>
        <location filename="../dbus/zcupsmonitor.cpp" line="385"/>
        <source>%1 %2, reason: %3</source>
        <translation>%1 %2, sebab: %3</translation>
    </message>
</context>
<context>
    <name>DriverManager</name>
    <message>
        <location filename="../../Common/vendor/zdrivermanager.cpp" line="1031"/>
        <source>EveryWhere driver</source>
        <translation>Pemacu EveryWhere</translation>
    </message>
</context>
<context>
    <name>InstallDriver</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="373"/>
        <source>Failed to find the driver solution: %1, error: %2</source>
        <translation>Gagal mencari penyelesaian pemacu: %1, ralat: %2</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="384"/>
        <source>The solution is invalid</source>
        <translation>Penyelesaian tidak sah</translation>
    </message>
</context>
<context>
    <name>InstallInterface</name>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="251"/>
        <source>is invalid</source>
        <translation>adalah tidak sah</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="280"/>
        <source>Failed to install the driver by calling dbus interface</source>
        <translation>Gagal memasang pemacu dengan memanggil antara muka dbus</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/addprinter.cpp" line="325"/>
        <source>Failed to install %1</source>
        <translation>Gagal memasang %1</translation>
    </message>
</context>
<context>
    <name>JobManager</name>
    <message>
        <location filename="../../Common/zjobmanager.cpp" line="307"/>
        <source> not found</source>
        <translation>tidak ditemui</translation>
    </message>
</context>
<context>
    <name>PrinterTestJob</name>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="370"/>
        <source>Check test page printing</source>
        <translation>Periksa cetakan halaman uji</translation>
    </message>
    <message>
        <location filename="../../Common/vendor/ztroubleshoot.cpp" line="424"/>
        <source>Printing test page...</source>
        <translation>Mencetak halaman uji...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Print Manager</source>
        <translation>Pengurus Cetak</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Print Manager is a printer management tool, which supports adding and removing printers, managing print jobs and so on.</source>
        <translation>Pengurus Cetak ialah sebuah alat pengurusan pencetak, yang menyokong penambahan dan pembuangan pencetak, pengurusan kerja cetak dan banyak lagi yang berkaitan.</translation>
    </message>
    <message>
        <location filename="../../Common/common.cpp" line="154"/>
        <source>%1 not found, please ask the administrator for help, or enter the printer IP address in URI of Properties.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>USBThread</name>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="260"/>
        <source>Configuring the printer %1 ...</source>
        <translation>Mengkonfigur pencetak %1 ...</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="306"/>
        <source>Configuration successful. Click to view %1.</source>
        <translation>Konfigurasi berjaya. Klik untuk lihat %1.</translation>
    </message>
    <message>
        <location filename="../usbprinter/usbthread.cpp" line="310"/>
        <source>Configuration failed. Click to add the printer %1.</source>
        <translation>Konfigurasi gagal. Klik untuk menambah pencetak %1.</translation>
    </message>
</context>
</TS>